@@ -1,9 +1,12 @@
-DEFINE_TEST(test_acl_freebsd_nfs4)
-DEFINE_TEST(test_acl_freebsd_posix1e_restore)
-DEFINE_TEST(test_acl_freebsd_posix1e_read)
 DEFINE_TEST(test_acl_nfs4)
-DEFINE_TEST(test_acl_pax)
+DEFINE_TEST(test_acl_pax_posix1e)
+DEFINE_TEST(test_acl_pax_nfs4)
+DEFINE_TEST(test_acl_platform_nfs4)
+DEFINE_TEST(test_acl_platform_posix1e_restore)
+DEFINE_TEST(test_acl_platform_posix1e_read)
 DEFINE_TEST(test_acl_posix1e)
+DEFINE_TEST(test_acl_from_text)
+DEFINE_TEST(test_acl_to_text)
 DEFINE_TEST(test_archive_api_feature)
 DEFINE_TEST(test_archive_clear_error)
 DEFINE_TEST(test_archive_cmdline)
@@ -113,8 +116,12 @@ DEFINE_TEST(test_compat_lzma)
 DEFINE_TEST(test_compat_lzop)
 DEFINE_TEST(test_compat_mac)
 DEFINE_TEST(test_compat_pax_libarchive_2x)
+DEFINE_TEST(test_compat_perl_archive_tar)
+DEFINE_TEST(test_compat_plexus_archiver_tar)
 DEFINE_TEST(test_compat_solaris_pax_sparse)
 DEFINE_TEST(test_compat_solaris_tar_acl)
+DEFINE_TEST(test_compat_star_acl_posix1e)
+DEFINE_TEST(test_compat_star_acl_nfs4)
 DEFINE_TEST(test_compat_tar_hardlink)
 DEFINE_TEST(test_compat_uudecode)
 DEFINE_TEST(test_compat_uudecode_large)
@@ -325,6 +332,7 @@ DEFINE_TEST(test_read_format_zip_filename_UTF8_CP1251)
 DEFINE_TEST(test_read_format_zip_filename_KOI8R_UTF8_2)
 DEFINE_TEST(test_read_format_zip_high_compression)
 DEFINE_TEST(test_read_format_zip_high_compression2)
+DEFINE_TEST(test_read_format_zip_jar)
 DEFINE_TEST(test_read_format_zip_mac_metadata)
 DEFINE_TEST(test_read_format_zip_malformed)
 DEFINE_TEST(test_read_format_zip_msdos)
@@ -342,6 +350,7 @@ DEFINE_TEST(test_read_format_zip_winzip_aes256_large)
 DEFINE_TEST(test_read_format_zip_zip64a)
 DEFINE_TEST(test_read_format_zip_zip64b)
 DEFINE_TEST(test_read_large)
+DEFINE_TEST(test_schily_xattr_pax)
 DEFINE_TEST(test_read_pax_truncated)
 DEFINE_TEST(test_read_position)
 DEFINE_TEST(test_read_set_format)
